==> haskell-fingertree-0.1.4.2-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fingertree.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fingertree
version:              0.1.4.2
visibility:           public
id:                   fingertree-0.1.4.2-GzF7VDBYvw3EXQ3Ntk6ba3
key:                  fingertree-0.1.4.2-GzF7VDBYvw3EXQ3Ntk6ba3
license:              BSD-3-Clause
copyright:            (c) 2006 Ross Paterson, Ralf Hinze
maintainer:           Ross Paterson <R.Paterson@city.ac.uk>
synopsis:             Generic finger-tree structure, with example instances
description:
    A general sequence representation with arbitrary
    annotations, for use as a base for implementations of
    various collection types, with examples, as described
    in section 4 of

    * Ralf Hinze and Ross Paterson,
    \"Finger trees: a simple general-purpose data structure\",
    /Journal of Functional Programming/ 16:2 (2006) pp 197-217.
    <http://staff.city.ac.uk/~ross/papers/FingerTree.html>

    For a tuned sequence type, see @Data.Sequence@ in the
    @containers@ package, which is a specialization of
    this structure.

category:             Data Structures
abi:                  71e5bf449a63088aac827adae1872c42
exposed:              True
exposed-modules:
    Data.FingerTree Data.IntervalMap.FingerTree
    Data.PriorityQueue.FingerTree

import-dirs:          /usr/lib/ghc-8.10.2/site-local/fingertree-0.1.4.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/fingertree-0.1.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/fingertree-0.1.4.2
hs-libraries:         HSfingertree-0.1.4.2-GzF7VDBYvw3EXQ3Ntk6ba3
depends:              base-4.14.1.0
haddock-interfaces:   /usr/share/doc/haskell-fingertree/html/fingertree.haddock
haddock-html:         /usr/share/doc/haskell-fingertree/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fingertree-0.1.4.2-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fingertree.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fingertree
version:              0.1.4.2
visibility:           public
id:                   fingertree-0.1.4.2-3iucl4kt52394C4n9tKMaf
key:                  fingertree-0.1.4.2-3iucl4kt52394C4n9tKMaf
license:              BSD-3-Clause
copyright:            (c) 2006 Ross Paterson, Ralf Hinze
maintainer:           Ross Paterson <R.Paterson@city.ac.uk>
synopsis:             Generic finger-tree structure, with example instances
description:
    A general sequence representation with arbitrary
    annotations, for use as a base for implementations of
    various collection types, with examples, as described
    in section 4 of

    * Ralf Hinze and Ross Paterson,
    \"Finger trees: a simple general-purpose data structure\",
    /Journal of Functional Programming/ 16:2 (2006) pp 197-217.
    <http://staff.city.ac.uk/~ross/papers/FingerTree.html>

    For a tuned sequence type, see @Data.Sequence@ in the
    @containers@ package, which is a specialization of
    this structure.

category:             Data Structures
abi:                  6c5e22dd4ee5e234380deb8e87d61209
exposed:              True
exposed-modules:
    Data.FingerTree Data.IntervalMap.FingerTree
    Data.PriorityQueue.FingerTree

import-dirs:          /usr/lib/ghc-8.10.2/site-local/fingertree-0.1.4.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/fingertree-0.1.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/fingertree-0.1.4.2
hs-libraries:         HSfingertree-0.1.4.2-3iucl4kt52394C4n9tKMaf
depends:              base-4.14.1.0
haddock-interfaces:   /usr/share/doc/haskell-fingertree/html/fingertree.haddock
haddock-html:         /usr/share/doc/haskell-fingertree/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
